/*
 * Jalview - A Sequence Alignment Editor and Viewer (Version 2.8.2)
 * Copyright (C) 2014 The Jalview Authors
 * 
 * This file is part of Jalview.
 * 
 * Jalview is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation, either version 3
 * of the License, or (at your option) any later version.
 *  
 * Jalview is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty 
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 * PURPOSE.  See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Jalview.  If not, see <http://www.gnu.org/licenses/>.
 * The Jalview Authors are detailed in the 'AUTHORS' file.
 */
package jalview.datamodel;

public interface AnnotatedCollectionI extends SequenceCollectionI
{

  /**
   * TODO: decide if null is a valid response if there is no annotation on the
   * object
   * 
   * @return null
   */
  AlignmentAnnotation[] getAlignmentAnnotation();

  Iterable<AlignmentAnnotation> findAnnotation(String calcId);

  /**
   * context for this annotated collection
   * 
   * @return null or the collection upon which this collection is defined (e.g.
   *         alignment, parent group).
   */
  AnnotatedCollectionI getContext();

  /**
   * Return an iterable set of any annotations in the collection that match the
   * provided criteria, i.e.
   * <ul>
   * <li>reference the same sequence datasequence</li>
   * <li>have the same calcId (source of annotation)</li>
   * <li>have the same label (type of annotation)</li>
   * </ul>
   * 
   * @param datasequence
   * @param calcId
   * @param label
   * @return
   */
  Iterable<AlignmentAnnotation> findAnnotation(SequenceI datasequence,
          String calcId, String label);
}
